@@ -25,14 +25,14 @@ class CheckServiceStatusRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'CheckServiceStatus','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SvcCode(self):
+	def get_SvcCode(self): # String
 		return self.get_query_params().get('SvcCode')
 
-	def set_SvcCode(self,SvcCode):
-		self.add_query_param('SvcCode',SvcCode)
\ No newline at end of file
+	def set_SvcCode(self, SvcCode):  # String
+		self.add_query_param('SvcCode', SvcCode)
