@@ -23,16 +23,16 @@ from aliyunsdkarms.endpoint import endpoint_data
 class DeleteAlertRulesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DeleteAlertRules')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DeleteAlertRules','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AlertIds(self):
+	def get_AlertIds(self): # String
 		return self.get_query_params().get('AlertIds')
 
-	def set_AlertIds(self,AlertIds):
-		self.add_query_param('AlertIds',AlertIds)
\ No newline at end of file
+	def set_AlertIds(self, AlertIds):  # String
+		self.add_query_param('AlertIds', AlertIds)
