@@ -31,8 +31,18 @@ class DeleteRetcodeAppRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_AppName(self): # String
+		return self.get_query_params().get('AppName')
+
+	def set_AppName(self, AppName):  # String
+		self.add_query_param('AppName', AppName)
 	def get_AppId(self): # String
 		return self.get_query_params().get('AppId')
 
 	def set_AppId(self, AppId):  # String
 		self.add_query_param('AppId', AppId)
+	def get_Pid(self): # String
+		return self.get_query_params().get('Pid')
+
+	def set_Pid(self, Pid):  # String
+		self.add_query_param('Pid', Pid)
