@@ -23,16 +23,16 @@ from aliyunsdkarms.endpoint import endpoint_data
 class DeleteScenarioRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DeleteScenario')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DeleteScenario','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ScenarioId(self):
+	def get_ScenarioId(self): # Long
 		return self.get_query_params().get('ScenarioId')
 
-	def set_ScenarioId(self,ScenarioId):
-		self.add_query_param('ScenarioId',ScenarioId)
\ No newline at end of file
+	def set_ScenarioId(self, ScenarioId):  # Long
+		self.add_query_param('ScenarioId', ScenarioId)
