@@ -23,16 +23,16 @@ from aliyunsdkarms.endpoint import endpoint_data
 class DescribeDispatchRuleRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DescribeDispatchRule')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DescribeDispatchRule','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Id(self):
+	def get_Id(self): # String
 		return self.get_query_params().get('Id')
 
-	def set_Id(self,Id):
-		self.add_query_param('Id',Id)
\ No newline at end of file
+	def set_Id(self, Id):  # String
+		self.add_query_param('Id', Id)
