@@ -25,14 +25,14 @@ class DescribePrometheusAlertRuleRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'DescribePrometheusAlertRule','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AlertId(self):
+	def get_AlertId(self): # Long
 		return self.get_query_params().get('AlertId')
 
-	def set_AlertId(self,AlertId):
-		self.add_query_param('AlertId',AlertId)
\ No newline at end of file
+	def set_AlertId(self, AlertId):  # Long
+		self.add_query_param('AlertId', AlertId)
