@@ -23,9 +23,11 @@ from aliyunsdkarms.endpoint import endpoint_data
 class GetAgentDownloadUrlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'GetAgentDownloadUrl')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'GetAgentDownloadUrl','arms')
 		self.set_method('GET')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
