@@ -23,9 +23,11 @@ from aliyunsdkarms.endpoint import endpoint_data
 class GetPrometheusApiTokenRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'GetPrometheusApiToken')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'GetPrometheusApiToken','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
