@@ -31,6 +31,11 @@ class ListCmsInstancesRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_TypeFilter(self): # String
+		return self.get_query_params().get('TypeFilter')
+
+	def set_TypeFilter(self, TypeFilter):  # String
+		self.add_query_param('TypeFilter', TypeFilter)
 	def get_ClusterId(self): # String
 		return self.get_query_params().get('ClusterId')
 
