@@ -23,26 +23,25 @@ from aliyunsdkarms.endpoint import endpoint_data
 class SaveTraceAppConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SaveTraceAppConfig')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SaveTraceAppConfig','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Settingss(self):
+	def get_Settingss(self): # RepeatList
 		return self.get_query_params().get('Settings')
 
-	def set_Settingss(self, Settingss):
-		for depth1 in range(len(Settingss)):
-			if Settingss[depth1].get('Value') is not None:
-				self.add_query_param('Settings.' + str(depth1 + 1) + '.Value', Settingss[depth1].get('Value'))
-			if Settingss[depth1].get('Key') is not None:
-				self.add_query_param('Settings.' + str(depth1 + 1) + '.Key', Settingss[depth1].get('Key'))
-
-	def get_Pid(self):
+	def set_Settingss(self, Settings):  # RepeatList
+		for depth1 in range(len(Settings)):
+			if Settings[depth1].get('Value') is not None:
+				self.add_query_param('Settings.' + str(depth1 + 1) + '.Value', Settings[depth1].get('Value'))
+			if Settings[depth1].get('Key') is not None:
+				self.add_query_param('Settings.' + str(depth1 + 1) + '.Key', Settings[depth1].get('Key'))
+	def get_Pid(self): # String
 		return self.get_query_params().get('Pid')
 
-	def set_Pid(self,Pid):
-		self.add_query_param('Pid',Pid)
\ No newline at end of file
+	def set_Pid(self, Pid):  # String
+		self.add_query_param('Pid', Pid)
