@@ -23,46 +23,41 @@ from aliyunsdkarms.endpoint import endpoint_data
 class SearchAlertContactRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SearchAlertContact')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SearchAlertContact','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_CurrentPage(self):
+	def get_CurrentPage(self): # String
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_ContactIds(self):
+	def set_CurrentPage(self, CurrentPage):  # String
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_ContactIds(self): # String
 		return self.get_query_params().get('ContactIds')
 
-	def set_ContactIds(self,ContactIds):
-		self.add_query_param('ContactIds',ContactIds)
-
-	def get_ContactName(self):
+	def set_ContactIds(self, ContactIds):  # String
+		self.add_query_param('ContactIds', ContactIds)
+	def get_ContactName(self): # String
 		return self.get_query_params().get('ContactName')
 
-	def set_ContactName(self,ContactName):
-		self.add_query_param('ContactName',ContactName)
-
-	def get_Phone(self):
+	def set_ContactName(self, ContactName):  # String
+		self.add_query_param('ContactName', ContactName)
+	def get_Phone(self): # String
 		return self.get_query_params().get('Phone')
 
-	def set_Phone(self,Phone):
-		self.add_query_param('Phone',Phone)
-
-	def get_PageSize(self):
+	def set_Phone(self, Phone):  # String
+		self.add_query_param('Phone', Phone)
+	def get_PageSize(self): # String
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Email(self):
+	def set_PageSize(self, PageSize):  # String
+		self.add_query_param('PageSize', PageSize)
+	def get_Email(self): # String
 		return self.get_query_params().get('Email')
 
-	def set_Email(self,Email):
-		self.add_query_param('Email',Email)
\ No newline at end of file
+	def set_Email(self, Email):  # String
+		self.add_query_param('Email', Email)
