@@ -23,64 +23,56 @@ from aliyunsdkarms.endpoint import endpoint_data
 class SearchEventsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SearchEvents')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'SearchEvents','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_IsTrigger(self):
+	def get_IsTrigger(self): # Integer
 		return self.get_query_params().get('IsTrigger')
 
-	def set_IsTrigger(self,IsTrigger):
-		self.add_query_param('IsTrigger',IsTrigger)
-
-	def get_AppType(self):
+	def set_IsTrigger(self, IsTrigger):  # Integer
+		self.add_query_param('IsTrigger', IsTrigger)
+	def get_AppType(self): # String
 		return self.get_query_params().get('AppType')
 
-	def set_AppType(self,AppType):
-		self.add_query_param('AppType',AppType)
-
-	def get_EndTime(self):
+	def set_AppType(self, AppType):  # String
+		self.add_query_param('AppType', AppType)
+	def get_EndTime(self): # Long
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_Pid(self):
+	def set_EndTime(self, EndTime):  # Long
+		self.add_query_param('EndTime', EndTime)
+	def get_Pid(self): # String
 		return self.get_query_params().get('Pid')
 
-	def set_Pid(self,Pid):
-		self.add_query_param('Pid',Pid)
-
-	def get_CurrentPage(self):
+	def set_Pid(self, Pid):  # String
+		self.add_query_param('Pid', Pid)
+	def get_CurrentPage(self): # Integer
 		return self.get_query_params().get('CurrentPage')
 
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
-	def get_StartTime(self):
+	def set_CurrentPage(self, CurrentPage):  # Integer
+		self.add_query_param('CurrentPage', CurrentPage)
+	def get_StartTime(self): # Long
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_AlertType(self):
+	def set_StartTime(self, StartTime):  # Long
+		self.add_query_param('StartTime', StartTime)
+	def get_AlertType(self): # Integer
 		return self.get_query_params().get('AlertType')
 
-	def set_AlertType(self,AlertType):
-		self.add_query_param('AlertType',AlertType)
-
-	def get_PageSize(self):
+	def set_AlertType(self, AlertType):  # Integer
+		self.add_query_param('AlertType', AlertType)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_AlertId(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_AlertId(self): # Long
 		return self.get_query_params().get('AlertId')
 
-	def set_AlertId(self,AlertId):
-		self.add_query_param('AlertId',AlertId)
\ No newline at end of file
+	def set_AlertId(self, AlertId):  # Long
+		self.add_query_param('AlertId', AlertId)
