@@ -23,16 +23,16 @@ from aliyunsdkarms.endpoint import endpoint_data
 class StopAlertRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'StopAlert')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'StopAlert','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AlertId(self):
+	def get_AlertId(self): # String
 		return self.get_query_params().get('AlertId')
 
-	def set_AlertId(self,AlertId):
-		self.add_query_param('AlertId',AlertId)
\ No newline at end of file
+	def set_AlertId(self, AlertId):  # String
+		self.add_query_param('AlertId', AlertId)
